@@ -1,9 +1,6 @@
 import requests
 
-from requests.exceptions import RequestException
-from urllib3.exceptions import MaxRetryError, ConnectTimeoutError
-from py_behrtech.parsers import Parser
-from py_behrtech.exceptions import JWTError, check_status_code
+from py_behrtech.exceptions import check_status_code
 
 
 class System:
@@ -29,6 +26,53 @@ class System:
         else:
             check_status_code(req=req)
 
+    def systemDatabaseDumpGet(self) -> dict:
+        """
+        Gets information about database dumpfiles and automatically deleted files
+
+        :return: Information about database dumpfiles and automatically deleted files
+        """
+
+        req = requests.get(url=self.server_address + f"/v2/system/databasedump", verify=False,
+                           headers={"Authorization": f"Bearer {self.jwt_token}"})
+
+        if req.status_code == 200:
+            return req.json()
+        else:
+            check_status_code(req=req)
+
+    def systemDatabaseDumpIdDelete(self, dumpFileId: str) -> dict:
+        """
+        Deletes the database dump file with the requested ID
+
+        :param dumpFileId: Unique database dump file ID
+        :return: Information on the deleted database dump file
+        """
+
+        req = requests.delete(url=self.server_address + f"/v2/system/databasedump/{dumpFileId}", verify=False,
+                              headers={"Authorization": f"Bearer {self.jwt_token}"})
+
+        if req.status_code == 200:
+            return req.json()
+        else:
+            check_status_code(req=req, messages={404: f"Database Dumpfile {dumpFileId} not found"})
+
+    def systemDatabaseDumpIdGet(self, dumpFileId: str) -> bool:
+        """
+        Starts a download of the database dump file with the requested ID
+
+        :param dumpFileId: Unique database dump file ID
+        :return: Bool if download is started
+        """
+
+        req = requests.get(url=self.server_address + f"/v2/system/databasedump/{dumpFileId}", verify=False,
+                           headers={"Authorization": f"Bearer {self.jwt_token}"})
+
+        if req.status_code == 200:
+            return True
+        else:
+            check_status_code(req=req, messages={404: f"Database Dumpfile {dumpFileId} not found"})
+
     def systemEulaGet(self) -> str:
         """
         Gets the end user license agreement
@@ -44,7 +88,7 @@ class System:
         else:
             check_status_code(req=req)
 
-    def systemGet(self) -> Parser:
+    def systemGet(self) -> dict:
         """
         Gets system status information
 
@@ -55,11 +99,11 @@ class System:
                            headers={"Authorization": f"Bearer {self.jwt_token}"})
 
         if req.status_code == 200:
-            return Parser(req=req)
+            return req.json()
         else:
             check_status_code(req=req)
 
-    def wsGet(self, access_token: str = None) -> Parser:
+    def wsGet(self, access_token: str = None) -> dict:
         """
         Request an upgrade to a websocket connection (Handshake is handled by goland http upgrader)
 
@@ -73,6 +117,6 @@ class System:
                            headers={"Authorization": f"Bearer {self.jwt_token}"})
 
         if req.status_code == 200:
-            return Parser(req=req)
+            return req.json()
         else:
             check_status_code(req=req)
